==> core-android-debug-1.17.0-sources.jar: androidMain/io/dyte/core/platform/DyteAndroidWebView.kt <==
package io.dyte.core.platform

import android.annotation.SuppressLint
import android.app.Activity.RESULT_OK
import android.content.Context
import android.content.Intent
import android.net.Uri
import android.webkit.JavascriptInterface
import android.webkit.ValueCallback
import android.webkit.WebChromeClient
import android.webkit.WebViewClient
import kotlinx.serialization.json.Json
import kotlinx.serialization.json.JsonObject
import kotlinx.serialization.json.jsonObject

actual typealias WebView = android.webkit.WebView

actual data class DytePluginFile(val resultCode: Int, val data: Intent? = null)

@SuppressLint("SetJavaScriptEnabled")
class DyteAndroidWebView internal constructor(private val utilsProvider: IDytePlatformUtilsProvider) : IDyteWebView {
  private var webView =
    android.webkit.WebView(utilsProvider.getPlatformUtils().getActivity() as Context)
  private var listener: IDyteWebViewListener? = null
  private var filePathCallback: ValueCallback<Array<Uri>>? = null
  private val jsWebViewInterface: WebViewInterface = WebViewInterface()

  override fun loadURL(url: String) {
    webView.loadUrl(url)
  }

  override fun initializeWebView() {
    bindWebView(webView)
  }

  override fun setListener(listener: IDyteWebViewListener) {
    this.listener = listener
    jsWebViewInterface.setInterfaceListener(listener)
  }

  override fun removeListener() {
    this.listener = null
    jsWebViewInterface.removeInterfaceListener()
  }

  override fun getWebView(): WebView {
    return webView
  }

  private fun bindWebView(webView: WebView) {
    with(webView) {
      settings.javaScriptEnabled = true
      settings.domStorageEnabled = true
      settings.databaseEnabled = true

      // Enables autoplay on Youtube plugin when a peer starts a video
      settings.mediaPlaybackRequiresUserGesture = false

      clearCache(true)
      clearHistory()

      webView.addJavascriptInterface(jsWebViewInterface, NAME_JS_INTERFACE)
      webView.webViewClient = object : WebViewClient() {
        override fun onPageFinished(view: android.webkit.WebView?, url: String?) {
          super.onPageFinished(view, url)
          view?.evaluateJavascript(jsListenerScript) {
            // no-op
          }
        }
      }

      webChromeClient = object : WebChromeClient() {
        override fun onShowFileChooser(
          webView: android.webkit.WebView?,
          filePathCallback: ValueCallback<Array<Uri>>?,
          fileChooserParams: FileChooserParams?
        ): Boolean {
          this@DyteAndroidWebView.filePathCallback = filePathCallback
          listener?.onFileRequest()
          return true
        }
      }
    }
  }

  override fun submitEvent(payload: JsonObject) {
    webView.evaluateJavascript(
      """
        window.postMessage($payload);
      """.trimIndent(),
      null
    )
  }

  override fun uploadFile(dytePluginFile: DytePluginFile) {
    if (dytePluginFile.resultCode == RESULT_OK && dytePluginFile.data != null) {
      filePathCallback?.onReceiveValue(
        WebChromeClient.FileChooserParams.parseResult(
          dytePluginFile.resultCode,
          dytePluginFile.data
        )
      )
    } else {
      filePathCallback?.onReceiveValue(null)
    }

    filePathCallback = null
  }

  companion object {
    private const val NAME_JS_INTERFACE = "WebViewInterface"
    private val jsListenerScript = """
      window.parent = {};
      window.parent.postMessage = function(message) {
        var formattedJSON = JSON.stringify(message);
        $NAME_JS_INTERFACE.postMessage(formattedJSON);
      };
      """.trimIndent()
  }

  private class WebViewInterface {
    private var interfaceListener: IDyteWebViewListener? = null

    fun setInterfaceListener(listener: IDyteWebViewListener) {
      this.interfaceListener = listener
    }

    fun removeInterfaceListener() {
      this.interfaceListener = null
    }

    @JavascriptInterface
    fun postMessage(messageJson: String) {
      interfaceListener?.onWebViewMessage(Json.parseToJsonElement(messageJson).jsonObject)
    }
  }
}

==> core-android-debug-1.20.1-sources.jar: androidMain/io/dyte/core/platform/DyteAndroidWebView.kt <==
package io.dyte.core.platform

import android.annotation.SuppressLint
import android.app.Activity.RESULT_OK
import android.content.Context
import android.content.Intent
import android.net.Uri
import android.webkit.JavascriptInterface
import android.webkit.ValueCallback
import android.webkit.WebChromeClient
import android.webkit.WebViewClient
import kotlinx.serialization.json.Json
import kotlinx.serialization.json.JsonObject
import kotlinx.serialization.json.jsonObject

actual typealias WebView = android.webkit.WebView

actual data class DytePluginFile(val resultCode: Int, val data: Intent? = null)

@SuppressLint("SetJavaScriptEnabled")
class DyteAndroidWebView
internal constructor(private val utilsProvider: IDytePlatformUtilsProvider) : IDyteWebView {
  private var webView =
    android.webkit.WebView(utilsProvider.getPlatformUtils().getActivity() as Context)
  private var listener: IDyteWebViewListener? = null
  private var filePathCallback: ValueCallback<Array<Uri>>? = null
  private val jsWebViewInterface: WebViewInterface = WebViewInterface()

  override fun loadURL(url: String) {
    webView.loadUrl(url)
  }

  override fun initializeWebView() {
    bindWebView(webView)
  }

  override fun setListener(listener: IDyteWebViewListener) {
    this.listener = listener
    jsWebViewInterface.setInterfaceListener(listener)
  }

  override fun removeListener() {
    this.listener = null
    jsWebViewInterface.removeInterfaceListener()
  }

  override fun getWebView(): WebView {
    return webView
  }

  private fun bindWebView(webView: WebView) {
    with(webView) {
      settings.javaScriptEnabled = true
      settings.domStorageEnabled = true
      settings.databaseEnabled = true

      // Enables autoplay on Youtube plugin when a peer starts a video
      settings.mediaPlaybackRequiresUserGesture = false

      clearCache(true)
      clearHistory()

      webView.addJavascriptInterface(jsWebViewInterface, NAME_JS_INTERFACE)
      webView.webViewClient =
        object : WebViewClient() {
          override fun onPageFinished(view: android.webkit.WebView?, url: String?) {
            super.onPageFinished(view, url)
            view?.evaluateJavascript(jsListenerScript) {
              // no-op
            }
          }
        }

      webChromeClient =
        object : WebChromeClient() {
          override fun onShowFileChooser(
            webView: android.webkit.WebView?,
            filePathCallback: ValueCallback<Array<Uri>>?,
            fileChooserParams: FileChooserParams?
          ): Boolean {
            this@DyteAndroidWebView.filePathCallback = filePathCallback
            listener?.onFileRequest()
            return true
          }
        }
    }
  }

  override fun submitEvent(payload: JsonObject) {
    webView.evaluateJavascript(
      """
        window.postMessage($payload);
      """
        .trimIndent(),
      null
    )
  }

  override fun uploadFile(dytePluginFile: DytePluginFile) {
    if (dytePluginFile.resultCode == RESULT_OK && dytePluginFile.data != null) {
      filePathCallback?.onReceiveValue(
        WebChromeClient.FileChooserParams.parseResult(
          dytePluginFile.resultCode,
          dytePluginFile.data
        )
      )
    } else {
      filePathCallback?.onReceiveValue(null)
    }

    filePathCallback = null
  }

  companion object {
    private const val NAME_JS_INTERFACE = "WebViewInterface"
    private val jsListenerScript =
      """
      window.parent = {};
      window.parent.postMessage = function(message) {
        var formattedJSON = JSON.stringify(message);
        $NAME_JS_INTERFACE.postMessage(formattedJSON);
      };
      """
        .trimIndent()
  }

  private class WebViewInterface {
    private var interfaceListener: IDyteWebViewListener? = null

    fun setInterfaceListener(listener: IDyteWebViewListener) {
      this.interfaceListener = listener
    }

    fun removeInterfaceListener() {
      this.interfaceListener = null
    }

    @JavascriptInterface
    fun postMessage(messageJson: String) {
      interfaceListener?.onWebViewMessage(Json.parseToJsonElement(messageJson).jsonObject)
    }
  }
}
